@@ -7,7 +7,8 @@ BADGES = {
     "sts": "Star Seller",
     "pro": "Promotion",
     "bes": "Best Seller",
-    "cns": "Low Stock"
+    "cns": "Low Stock",
+    "etp": "Etsy Pick"
 }
 
 class Listing(BaseModel):
@@ -26,4 +27,4 @@ class Result(BaseModel):
     
     @property
     def all_listings(self):
-        return self.organic_listings + self.ad_listings
\ No newline at end of file
+        return self.organic_listings + self.ad_listings
